==> localstack-ext-0.13.0.4.tar.gz: localstack-ext-0.13.0.4/localstack_ext/bootstrap/decryption.py <==
import inspect
pTcxh=bytes
pTcxS=None
pTcxt=isinstance
pTcxq=list
pTcxm=getattr
pTcxQ=open
pTcxl=property
pTcxj=Exception
pTcxD=setattr
pTcxs=True
import os.path
import sys
import traceback
from importlib.abc import MetaPathFinder,SourceLoader
from importlib.util import spec_from_file_location
import pyaes
class DecryptionHandler:
 decryption_key:pTcxh
 def __init__(self,decryption_key:pTcxh):
  self.decryption_key=decryption_key
 def decrypt(self,content)->pTcxh:
  cipher=pyaes.AESModeOfOperationCBC(self.decryption_key,iv="\0"*16)
  decrypter=pyaes.Decrypter(cipher)
  decrypted=decrypter.feed(content)
  decrypted+=decrypter.feed()
  decrypted=decrypted.partition(b"\0")[0]
  return decrypted
class EncryptedFileFinder(MetaPathFinder):
 decryption_handler:DecryptionHandler
 def __init__(self,decryption_handler:DecryptionHandler):
  self.decryption_handler=decryption_handler
 def find_spec(self,fullname,path,target=pTcxS):
  if path and not pTcxt(path,pTcxq):
   path=pTcxq(pTcxm(path,"_path",[]))
  if not path:
   return pTcxS
  name=fullname.split(".")[-1]
  file_path=os.path.join(path[0],name+".py")
  enc=file_path+".enc"
  if not os.path.isfile(enc):
   return pTcxS
  if os.path.isfile(file_path):
   return pTcxS
  return spec_from_file_location(fullname,enc,loader=DecryptingLoader(enc,self.decryption_handler))
class DecryptingLoader(SourceLoader):
 decryption_handler:DecryptionHandler
 def __init__(self,encrypted_file,decryption_handler:DecryptionHandler):
  self.encrypted_file=encrypted_file
  self.decryption_handler=decryption_handler
 def get_filename(self,fullname):
  return self.encrypted_file
 def get_data(self,filename):
  with pTcxQ(filename,"rb")as f:
   data=f.read()
  data=self.decryption_handler.decrypt(data)
  return data
def init_source_decryption(decryption_handler:DecryptionHandler):
 sys.meta_path.insert(0,EncryptedFileFinder(decryption_handler))
 patch_traceback_lines()
 patch_inspect_findsource()
def patch_traceback_lines():
 if pTcxm(traceback.FrameSummary,"_ls_patch_applied",pTcxS):
  return
 @pTcxl
 def line(self):
  try:
   return line_orig.fget(self)
  except pTcxj:
   self._line=""
   return self._line
 line_orig=traceback.FrameSummary.line
 pTcxD(traceback.FrameSummary,"line",line)
 traceback.FrameSummary._ls_patch_applied=pTcxs
def patch_inspect_findsource():
 if pTcxm(inspect,"_ls_patch_applied",pTcxS):
  return
 def findsource(*args,**kwargs):
  try:
   return findsource_orig(*args,**kwargs)
  except pTcxj:
   return[],0
 findsource_orig=inspect.findsource
 inspect.findsource=findsource
 inspect._ls_patch_applied=pTcxs
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.14.0.21.tar.gz: localstack-ext-0.14.0.21/localstack_ext/bootstrap/decryption.py <==
import inspect
import os.path
import sys
import traceback
from importlib.abc import MetaPathFinder,SourceLoader
from importlib.util import spec_from_file_location
import pyaes
class DecryptionHandler:
 decryption_key:bytes
 def __init__(self,decryption_key:bytes):
  self.decryption_key=decryption_key
 def decrypt(self,content)->bytes:
  cipher=pyaes.AESModeOfOperationCBC(self.decryption_key,iv="\0"*16)
  decrypter=pyaes.Decrypter(cipher)
  decrypted=decrypter.feed(content)
  decrypted+=decrypter.feed()
  decrypted=decrypted.partition(b"\0")[0]
  return decrypted
class EncryptedFileFinder(MetaPathFinder):
 decryption_handler:DecryptionHandler
 def __init__(self,decryption_handler:DecryptionHandler):
  self.decryption_handler=decryption_handler
 def find_spec(self,fullname,path,target=None):
  if path and not isinstance(path,list):
   path=list(getattr(path,"_path",[]))
  if not path:
   return None
  name=fullname.split(".")[-1]
  file_path=os.path.join(path[0],name+".py")
  enc=file_path+".enc"
  if not os.path.isfile(enc):
   return None
  if os.path.isfile(file_path):
   return None
  return spec_from_file_location(fullname,enc,loader=DecryptingLoader(enc,self.decryption_handler))
class DecryptingLoader(SourceLoader):
 decryption_handler:DecryptionHandler
 def __init__(self,encrypted_file,decryption_handler:DecryptionHandler):
  self.encrypted_file=encrypted_file
  self.decryption_handler=decryption_handler
 def get_filename(self,fullname):
  return self.encrypted_file
 def get_data(self,filename):
  with open(filename,"rb")as f:
   data=f.read()
  data=self.decryption_handler.decrypt(data)
  return data
def init_source_decryption(decryption_handler:DecryptionHandler):
 sys.meta_path.insert(0,EncryptedFileFinder(decryption_handler))
 patch_traceback_lines()
 patch_inspect_findsource()
def patch_traceback_lines():
 if getattr(traceback.FrameSummary,"_ls_patch_applied",None):
  return
 @property
 def line(self):
  try:
   return line_orig.fget(self)
  except Exception:
   self._line=""
   return self._line
 line_orig=traceback.FrameSummary.line
 setattr(traceback.FrameSummary,"line",line)
 traceback.FrameSummary._ls_patch_applied=True
def patch_inspect_findsource():
 if getattr(inspect,"_ls_patch_applied",None):
  return
 def findsource(*args,**kwargs):
  try:
   return findsource_orig(*args,**kwargs)
  except Exception:
   return[],0
 findsource_orig=inspect.findsource
 inspect.findsource=findsource
 inspect._ls_patch_applied=True
# Created by pyminifier (https://github.com/liftoff/pyminifier)
